@@ -36,7 +36,7 @@
 #'
 #' @export
 #'
-#' @examples
+#' @examplesIf check_eccc()
 #'
 #' stations()
 #' stations_meta()
@@ -63,18 +63,22 @@ stations <- function() {
 #'
 #' @export
 #'
-#' @examples
+#' @examplesIf check_eccc()
 #' stations_meta()
 stations_meta <- function() {
   stations_read()$meta
 }
 
 stations_read <- function() {
-  if(!file.exists(stations_file())) {
-    f <- system.file("extdata", "stations.rds", package = "weathercan")
-  } else f <- stations_file()
+  pkg_file <- system.file("extdata", "stations.rds", package = "weathercan") %>%
+    readr::read_rds()
 
-  readr::read_rds(f)
+  if (file.exists(stations_file())) {
+    local_file <- stations_file() %>%
+      readr::read_rds()
+    if(pkg_file$meta$ECCC_modified < local_file$meta$ECCC_modified) return(local_file)
+  }
+  pkg_file
 }
 
 stations_file <- function() {
@@ -113,16 +117,13 @@ stations_file <- function() {
 #'   missing data, etc.)
 #'
 #'
-#' @examples
+#' @examplesIf check_eccc()
 #'
-#' if(interactive()) {
-#'   # Update stations data frame
-#'   stations_dl()
-#'
-#'   # Updated stations data frame is now automatically used
-#'   stations_search("Winnipeg")
-#' }
+#' # Update stations data frame
+#' stations_dl()
 #'
+#' # Updated stations data frame is now automatically used
+#' stations_search("Winnipeg")
 #'
 #' @export
 
@@ -134,6 +135,7 @@ stations_dl <- function(skip = NULL, verbose = FALSE, quiet = FALSE) {
 stations_dl_internal <- function(skip = NULL, verbose = FALSE, quiet = FALSE,
                                  internal = TRUE) {
 
+
   if(getRversion() <= "3.3.3") {
     message("Need R version 3.3.4 or greater to update the stations data")
     return()
@@ -150,7 +152,7 @@ stations_dl_internal <- function(skip = NULL, verbose = FALSE, quiet = FALSE,
 
   # Ask for permission to save data
   if(!internal) {
-    if(!dir.exists(d) || !file.exists(f)) {
+    if((!dir.exists(d) || !file.exists(f)) && interactive()) {
       cont <- utils::askYesNo(
         paste0("weathercan would like to store the updated stations ",
                "data to: \n", f, "\nIs that okay?"))
@@ -161,7 +163,7 @@ stations_dl_internal <- function(skip = NULL, verbose = FALSE, quiet = FALSE,
       return(invisible())
     }
 
-    if(!dir.exists(d)) dir.create(d)
+    if(!dir.exists(d)) dir.create(d, recursive = TRUE)
   }
 
   if(!requireNamespace("lutz", quietly = TRUE) |
@@ -210,9 +212,10 @@ stations_dl_internal <- function(skip = NULL, verbose = FALSE, quiet = FALSE,
 
   if(verbose) message("Downloading stations data frame")
 
-  s <- httr::content(resp, type = "text/csv", encoding = "Latin1",
-                     skip = skip, col_types = readr::cols()) %>%
-    dplyr::select(prov = "Province",
+  raw <- httr::content(resp, as = "text", encoding = "Latin1")
+
+  s <- readr::read_delim(raw, skip = skip, col_types = readr::cols())
+  s <- dplyr::select(s, prov = "Province",
                   station_name = "Name",
                   station_id = "Station ID",
                   climate_id = "Climate ID",
@@ -331,7 +334,7 @@ stations_dl_internal <- function(skip = NULL, verbose = FALSE, quiet = FALSE,
 #'   the distance in kilometres from the location to the station. If no stations
 #'   are found withing `dist`, the closest 10 stations are returned.
 #'
-#' @examples
+#' @examplesIf check_eccc()
 #'
 #' stations_search(name = "Kamloops")
 #' stations_search(name = "Kamloops", interval = "hour")
